import request from '@/utils/request'

// 项目类型表列表
export function apiProjecttypeLists(params: any) {
    return request.get({ url: '/project.project_type_set/lists', params })
}

// 添加项目类型
export function apiProjecttypeAdd(params: any) {
    return request.post({ url: '/project.project_type_set/add', params })
}

// 编辑项目类型
export function apiProjecttypeEdit(params: any) {
    return request.post({ url: '/project.project_type_set/edit', params })
}

// 删除项目类型
export function apiProjecttypeDelete(params: any) {
    return request.post({ url: '/project.project_type_set/delete', params })
}


// 项目类型详情
export function apiProjecttypDetail(params: any) {
    return request.get({ url: '/project.project_type_set/detail', params })
}

//获取所有项目类型
export function getAllProjectTypes(params: any) {
    return request.post({ url: '/project.project_type_set/getAllProjectTypes', params })
}